#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
import time
import json
from infra_cep_helper import CEPCollecting


def prepare_tags(d):
    if isinstance(d, dict):
        for key in d.keys():
            prepare_tags(d[key])
            new_tag = key.replace(" ", "")
            if key[0].isdigit():
                new_tag = "_" + new_tag
            d[new_tag] = d.pop(key)
    else:
        return


class Networking(CEPCollecting):
    def fill_results(self):
        retries = 1
        succeed = False
        fail_reason = "Unknown reason"
        while not succeed and retries < 4:
            try:
                out = self.execute_shell("/usr/sbin/ip -o link")
                devices = []
                regex = re.compile("\d+:\s+([^:]+):(.*)$")
                for l in out.splitlines():
                    (name, value) = re.findall(regex, l)[0]
                    devices.insert(0, {name: value})
                self.result["Devices"] = devices

                cmd = "/usr/sbin/iptables -L"
                self.result["Iptables"] = self.execute_shell(cmd)

                cmd = "/usr/bin/prlsrvctl net list --json"
                out = self.execute_shell(cmd)
                networks = json.loads(out)
                for network in networks:
                    prepare_tags(network)
                    network["XmlLabel"] = "Network"
                self.result["VirtualNetworks"] = networks
                succeed = True
            except Exception as e:
                succeed = False
                fail_reason = str(e)
                time.sleep(60 * 2 * retries)
                retries += 1
        if not succeed:
            raise StandardError("Unable to collect networking info: " + fail_reason)


def main():
    o = Networking()
    o.run()


if __name__ == "__main__":
    main()
